@@ -23,11 +23,10 @@ class ExampleContext(BaseModel):
         ["mingw73_32", "mingw730_32"],
     ]
 
-    enable_3rd_module: bool = False
-
     x64_arch: bool = None
     qt_compile_version: str = None
     qt_tool_version: str = None
+    enable_3rd_module: bool = None
 
 
 def example_user_input_context_hook(context: dict) -> dict:
@@ -58,6 +57,7 @@ create_example_qml = generate_create_project_command(
     raw_user_input_context=USER_INPUT_CONTEXT
     | ExampleContext().dict(exclude_none=True),
     user_input_context_hook=example_user_input_context_hook,
+    editors=["clion", "code"],
 )
 
 create_example.add_command(create_example_qml, "qml")
@@ -66,8 +66,9 @@ create_example_console = generate_create_project_command(
     command_help="Create a cpp qt5 console example project scaffold.",
     template_paths=TEMPLATE_CPP_QT5_EXAMPLE_PATH / "console",
     raw_user_input_context=USER_INPUT_CONTEXT
-    | ExampleContext().dict(exclude_none=True),
+    | ExampleContext(enable_3rd_module=False).dict(exclude_none=True),
     user_input_context_hook=example_user_input_context_hook,
+    editors=["clion", "code"],
 )
 
 create_example.add_command(create_example_console, "console")
