@@ -4,9 +4,10 @@ from pathlib import Path
 from typing import NamedTuple, Union
 
 import click
-from cookiecutter.prompt import read_user_choice
+from cookiecutter.prompt import read_user_choice, read_user_yes_no
 
-from toolkit.scaffold.project import golang, python
+from toolkit.scaffold.project import cpp, golang, python
+from toolkit.scaffold.project.cpp import qt5
 from toolkit.template.code_style import get_camel_case_styles
 
 ARTICLE_SETTINGS_PATH = "assets/templates/article_settings.yaml"
@@ -27,9 +28,15 @@ url:  "{url}"  # 设置网页永久链接
 
 
 class ProgrammingLanguage(NamedTuple):
-    python: str = "python"
-    golang: str = "golang"
+    none: str = "none"
+
     cpp: str = "cpp"
+    golang: str = "golang"
+    kotlin: str = "kotlin"
+    python: str = "python"
+    qt5: str = "qt5"
+    qt6: str = "qt6"
+    rust: str = "rust"
 
 
 L = ProgrammingLanguage()
@@ -52,7 +59,7 @@ def render_article_content(
         ARTICLE_HEADER_SEPARATOR
         + ARTICLE_HEADER_CREATOR
         + "\n"
-        + ARTICLE_HEADER_TITLE.format(title=project_slugs[2], url=url)
+        + ARTICLE_HEADER_TITLE.format(title=project_slugs.pascal_case, url=url)
     )
 
     if os.path.isfile(ARTICLE_SETTINGS_PATH):
@@ -65,7 +72,7 @@ def render_article_content(
         with open(ARTICLE_CONTENT_PATH, encoding="utf-8") as fp:
             article_content += (fp.read() + "\n\n") * 3
 
-    return article_content
+    return article_content.strip() + "\n"
 
 
 @click.command(help="Create a new article.")
@@ -124,17 +131,42 @@ def create_article(
 
         language = read_user_choice("Language", list(L))
 
+        src_project_path = os.path.join("src", os.path.splitext(article_path)[0])
+
         if language == L.python:
             ctx.invoke(
                 python.create_example,
-                project_path=os.path.join("src", os.path.splitext(article_path)[0]),
+                project_path=src_project_path,
+                ignored_items=",".join(["README.md"]),
                 overwrite=False,
             )
         elif language == L.golang:
             ctx.invoke(
                 golang.create_example_console,
-                project_path=os.path.join("src", os.path.splitext(article_path)[0]),
+                project_path=src_project_path,
+                ignored_items=",".join(["README.md"]),
                 overwrite=False,
             )
         elif language == L.cpp:
-            pass
+            ctx.invoke(
+                cpp.create_example,
+                project_path=src_project_path,
+                ignored_items=",".join(["README.md"]),
+                overwrite=False,
+            )
+        elif language == L.kotlin:
+            # Kotlin project is complex, so it doesn't create an example automatically.
+            # Use IntelliJ IEDA to create it.
+            if read_user_yes_no("Launch explorer?", "yes"):
+                os.makedirs(src_project_path, exist_ok=True)
+                click.launch(src_project_path, locate=True)
+        elif language == L.qt5:
+            choice = read_user_choice("Application", ["console", "qml"])
+            ctx.invoke(
+                qt5.create_example_console
+                if choice == "console"
+                else qt5.create_example_qml,
+                project_path=src_project_path,
+                ignored_items=",".join(["README.md"]),
+                overwrite=False,
+            )
