@@ -1,15 +1,22 @@
+#include <QFont>
 #include <QGuiApplication>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
-#include <QFont>
+#include <QQuickStyle>
 
 #include "core.h"
 
 int main(int argc, char *argv[]) {
   QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 
+  QCoreApplication::setApplicationName("QtExampleApplication");
+  QCoreApplication::setOrganizationName("QtExampleOrganization");
+  QCoreApplication::setOrganizationDomain("qt.example.com");
+
   QGuiApplication app(argc, argv);
 
+  QQuickStyle::setStyle("Material");
+
   QGuiApplication::setFont(QFont("Microsoft YaHei", 14));
 
   Core *core = new Core(&app);
