@@ -1,6 +1,6 @@
 package form
 
-type {{ factory.entity|title }}Create struct {
+type {{ factory.entity_slug.pascal_case }}Create struct {
 	When  string `json:"when" binding:"required" example:"时间"`
 	Where string `json:"where" binding:"required" example:"地点"`
 	Who   string `json:"who" binding:"required" example:"人物"`
@@ -8,7 +8,7 @@ type {{ factory.entity|title }}Create struct {
 	How   string `json:"how" binding:"required" example:"过程"`
 }
 
-type {{ factory.entity|title }}Update struct {
+type {{ factory.entity_slug.pascal_case }}Update struct {
 	When  string `json:"when" example:"时间"`
 	Where string `json:"where" example:"地点"`
 	Who   string `json:"who" example:"人物"`
